variable "region" {
  default = "us-east-1"
}

provider "aws" {
  region = "${var.region}"
}

resource "aws_lambda_function" "lambda-jsonapi" {
  function_name = "lambda-jsonapi"

  # The bucket name as created before running terraform scripts with "aws s3api create-bucket"
  s3_bucket = "lambda-jsonapi-code-bucket"
  s3_key    = "v1.0.0/lambda-jsonapi.zip"

  # "main" is the filename within the zip file (main.js) and "handler"
  # is the name of the property under which the handler function was
  # exported in that file.
  handler = "lambda-jsonapi.handler"
  runtime = "nodejs8.10"

  role = "${aws_iam_role.lambda_jsonapi.arn}"
}


# Allow API Gateway to access the defined lambda function
resource "aws_lambda_permission" "apigw" {
  statement_id  = "AllowAPIGatewayInvoke"
  action        = "lambda:InvokeFunction"
  function_name = "${aws_lambda_function.lambda-jsonapi.arn}"
  principal     = "apigateway.amazonaws.com"

  # The /*/* portion grants access from any method on any resource
  # within the API Gateway "REST API".
  source_arn = "${aws_api_gateway_deployment.jsonapiDeployment.execution_arn}/*/*"
}